pub unsafe extern "C" fn tract_runnable_profile_json(
model: *mut TractRunnable,
inputs: *mut *mut TractTensor,
json: *mut *mut i8,
) -> TRACT_RESULTExpand description
Perform a profile of the model using the provided inputs.
pub unsafe extern "C" fn tract_runnable_profile_json(
model: *mut TractRunnable,
inputs: *mut *mut TractTensor,
json: *mut *mut i8,
) -> TRACT_RESULTPerform a profile of the model using the provided inputs.