tract_runtime_prepare

Function tract_runtime_prepare 

pub unsafe extern "C" fn tract_runtime_prepare(
    runtime: *const TractRuntime,
    model: *mut *mut TractModel,
    runnable: *mut *mut TractRunnable,
) -> TRACT_RESULT
Convert a Model into a Runnable for this Runtime.

This function transfers ownership of the model argument to the newly-created runnable model.

Runnable are reference counted. When done, it should be released with tract_runnable_release.