tract_state_clone

Function tract_state_clone 

pub unsafe extern "C" fn tract_state_clone(
    state: *const TractState,
    clone: *mut *mut TractState,
) -> TRACT_RESULT
Clone a State, creating an independent copy.

clone will be overwritten with a pointer to the new state. The new state must eventually be destroyed with tract_state_destroy.