pub unsafe extern "C" fn tract_tensor_dump(
tensor: *const TractTensor,
spec: *mut *mut c_char,
) -> TRACT_RESULTExpand description
Write a tensor as a debug string
The returned string must be freed by the caller using tract_free_cstring.
pub unsafe extern "C" fn tract_tensor_dump(
tensor: *const TractTensor,
spec: *mut *mut c_char,
) -> TRACT_RESULTWrite a tensor as a debug string
The returned string must be freed by the caller using tract_free_cstring.