tract_value_convert_to

Function tract_value_convert_to 

pub unsafe extern "C" fn tract_value_convert_to(
    input: *const TractValue,
    datum_type: DatumType,
    output: *mut *mut TractValue,
) -> TRACT_RESULT
Convert a value to a new datum type.

This function will perform a cheap shallow clone if the destination type is the same as the current type, otherwise it returns a newly allocated Value instead.

In both cases, the returned value must be destroyed by tract_value_destroy. The input value is not consumed, it still need to be destroyed.