pub unsafe extern "C" fn tract_value_dump(
value: *const TractValue,
spec: *mut *mut c_char,
) -> TRACT_RESULTExpand description
Write a value as a debug string
The returned string must be freed by the caller using tract_free_cstring.
pub unsafe extern "C" fn tract_value_dump(
value: *const TractValue,
spec: *mut *mut c_char,
) -> TRACT_RESULTWrite a value as a debug string
The returned string must be freed by the caller using tract_free_cstring.