pub unsafe extern "C" fn tract_runtime_for_name(
name: *const c_char,
nnef: *mut *mut TractRuntime,
) -> TRACT_RESULTExpand description
Creates an instance of a tract Runtime that can be used to run model on a specific hardware / software stack (like a GPU).
The returned object should be released with tract_runtime_release.